==> Persian-Date-Picker-Dialog-1.6.1-sources.jar: ir/hamsaa/persiandatepicker/util/PersianHelper.java <==
package ir.hamsaa.persiandatepicker.util;

/**
 * Created by sajjad on 01/18/2016.
 */
public class PersianHelper {
    private static char[] persianNumbers = new char[]{'۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹'};
    private static char[] englishNumbers = new char[]{'0', '1', '2', '3', '4', '5', '6', '7', '8', '9'};

    public static String toPersianNumber(String text) {
        if (text.isEmpty())
            return "";
        String out = "";
        int length = text.length();
        for (int i = 0; i < length; i++) {
            char c = text.charAt(i);
            if ('0' <= c && c <= '9') {
                int number = Integer.parseInt(String.valueOf(c));
                out += persianNumbers[number];
            } else if (c == '٫') {
                out += '،';
            } else {
                out += c;
            }

        }
        return out;
    }

    public static String toEnglishNumber(String text) {
        if (text.isEmpty())
            return "";
        String out = "";
        int length = text.length();

        for (int i = 0; i < length; i++) {
            char c = text.charAt(i);

            int charPos;
            if ((charPos = hasCharachter(c)) != -1) {
                out += englishNumbers[charPos];
            } else if (c == '،') {
                out += '٫';
            } else {
                out += c;
            }

        }

        return out;
    }

    private static int hasCharachter(char c) {
        for (int i = 0; i < persianNumbers.length; i++) {
            if (c == persianNumbers[i]) {
                return i;
            }
        }
        return -1;
    }
}

==> Persian-Date-Picker-Dialog-1.8.0-sources.jar: ir/hamsaa/persiandatepicker/util/PersianHelper.java <==
package ir.hamsaa.persiandatepicker.util;

public class PersianHelper {
    private static final char[] persianNumbers = new char[]{'۰', '۱', '۲', '۳', '۴', '۵', '۶', '۷', '۸', '۹'};
    private static final char[] englishNumbers = new char[]{'0', '1', '2', '3', '4', '5', '6', '7', '8', '9'};

    public static String toPersianNumber(String text) {
        if (text.isEmpty())
            return "";
        StringBuilder out = new StringBuilder();
        int length = text.length();
        for (int i = 0; i < length; i++) {
            char c = text.charAt(i);
            if ('0' <= c && c <= '9') {
                int number = Integer.parseInt(String.valueOf(c));
                out.append(persianNumbers[number]);
            } else if (c == '٫') {
                out.append('،');
            } else {
                out.append(c);
            }

        }
        return out.toString();
    }

    public static String toEnglishNumber(String text) {
        if (text.isEmpty())
            return "";
        StringBuilder out = new StringBuilder();
        int length = text.length();

        for (int i = 0; i < length; i++) {
            char c = text.charAt(i);

            int charPos;
            if ((charPos = hasCharachter(c)) != -1) {
                out.append(englishNumbers[charPos]);
            } else if (c == '،') {
                out.append('٫');
            } else {
                out.append(c);
            }

        }

        return out.toString();
    }

    private static int hasCharachter(char c) {
        for (int i = 0; i < persianNumbers.length; i++) {
            if (c == persianNumbers[i]) {
                return i;
            }
        }
        return -1;
    }
}
